import { Controller, Get, Inject, Query } from '@midwayjs/core';
import { NeedLoginMiddleware } from '../middleware/needLogin.middleware';
import { ContactSearchService } from '../service/contactSearch.service';

/**
 * 预约对接查询匹配度
 */
@Controller('/cs', { middleware: [NeedLoginMiddleware] })
export class ContactSearchController {
  @Inject()
  csService: ContactSearchService;
  /**
   * 来源是需求的匹配查询
   * 需要查询 当前用户 通过审核的 供给和成果数据
   * @param keyword 关键词
   */
  @Get('/demand')
  async demand(@Query('keyword') keyword: string, @Query('id') id: number) {
    if (!keyword) return;
    const supplyConfig = { index: 'supply', fields: ['name', 'tags', 'brief'] };
    // const sres = await this.csService.search(keyword, supplyConfig, 'demand', id);
    const sres = await this.csService.newSearch(keyword, supplyConfig, 'demand', id);
    const achievementConfig = { index: 'achievement', fields: ['name', 'tags', 'brief'] };
    // const ares = await this.csService.search(keyword, achievementConfig, 'demand', id);
    const ares = await this.csService.newSearch(keyword, achievementConfig, 'demand', id);
    const projectConfig = { index: 'project' };
    const pres = await this.csService.newSearch(keyword, projectConfig, 'demand', id);
    return sres || ares || pres;
  }

  /**
   * 来源是供给的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/supply')
  async supply(@Query('keyword') keyword: string, @Query('id') id: number) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    // const res = await this.csService.search(keyword, config, 'supply', id);
    const res = await this.csService.newSearch(keyword, config, 'supply', id);
    return res;
  }

  /**
   * 来源是项目的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/project')
  async projectr(@Query('keyword') keyword: string, @Query('id') id: number) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    // const res = await this.csService.search(keyword, config, 'project', id);
    const res = await this.csService.newSearch(keyword, config, 'project', id);
    return res;
  }

  /**
   * 来源是成果的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/achievement')
  async achievement(@Query('keyword') keyword: string, @Query('id') id: number) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    // const res = await this.csService.search(keyword, config, 'achievement', id);
    const res = await this.csService.newSearch(keyword, config, 'achievement', id);
    return res;
  }
}
